/*
	GTK Drag & Drop Tutorial - Example Source Code

	Copyright (C) 2000-2002 WolfPack Entertainment
	http://wolfpack.twu.net/


	To compile:

		cc `gtk-config --cflags --libs` dnd.c -o dnd


	Important: DND does not appear to work properly with GTK+ 1.2.9
	or older!!  Please try to obtain GTK+ 1.2.10 or newer before
	attempting to run this demo.


	Order of GTK DND events are as follows (for one complete drag
	and drop operation):

	1. "drag_begin_event"	notifies source that drag started
	2. "drag_motion"	notifies target about drag pointer motion
	3. "drag_data_get"	request for drag data from source
	4. "drag_data_received"	source has sent target the requested data
	5. "drag_data_delete"	source should/can delete data
	6. "drag_end_event"	notifies source that drag is done

	Sequences 1, 3, 5, and 6 are sent to the source widget, while
	sequences 2 and 4 are sent to the target widget.

 */

#include <gdk/gdkx.h>	/* Needed for pixmap loading. */
#include <gtk/gtk.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

//#include <eggtrayicon.h>
//#include <eggtrayicon.c>

GdkBitmap	*mask;  
GtkWidget *pixmapwid;

int iconcounter=0;
GtkButton *button[100];
int hidden = 0;


void parseConfigFile(void);	
void hideWindows(void);	
//void button_click( GtkWidget *widget, gpointer   data );
void button_click( GtkWidget *widget,  GdkEventButton *event);
char *strrepl(char *Str, size_t BufSiz, char *OldStr, char *NewStr);

char mycmd[20000];
gchar *new_text;
char thepic[1024];

struct{
  char torun[1024];
  char torunclick1[1024];
  char torunclick2[1024];
  char torunclick3[1024];
  char tooltip[1024];
  char picname[1024];
  char alarmpicname[1024];
  int alarmactive;
  GtkWidget *buttonpic;
  GdkPixbuf *ipixbuf;
 
//} action[1];
} action[100];


/*
 *	DND data format type idenficaition, it identifies what format
 *	the drag data is in for internal parsing by this program.
 *	Remember that this is the data format type (not to be confused
 *	with data type, like string, binary, etc).
 *
 *	These values are passed to gtk_drag_dest_set() and
 *	gtk_drag_source_set() and will be given as inputs in DND signal
 *	callbacks.
 *
 *	In each callback, we have the choice of using either the name 
 *	(a string) or the info (an int).  In this example we will use
 *	the info (an int) since it is easier and more commonly practiced.
 *
 *	Below we define the name and info pairs that are commonly used
 *	in most GTK+ and GNOME applications:
 */
#define DRAG_TAR_NAME_0		"text/uri-list"		/* not url-list */
#define DRAG_TAR_INFO_0		1

#define DRAG_TAR_NAME_1		"text/plain"
#define DRAG_TAR_INFO_1		0

//#define DRAG_TAR_NAME_1		"text/uri-list"		/* not url-list */
//#define DRAG_TAR_INFO_1		1

#define DRAG_TAR_NAME_2		"STRING"
#define DRAG_TAR_INFO_2		2


/*
 *	Our window structure, it's just a toplevel GtkWindow and a
 *	GtkCList.  The GtkCList will not be set reorderable, so that
 *	we can demostrate the (more advanced) DND abilities of this
 *	program.
 */
typedef struct {

	GtkWidget *toplevel;
	GtkWidget *button;

} my_prog_window_struct;
my_prog_window_struct *win[100];
//my_prog_window_struct *win[1];

/* General event/signal callbacks. */
static gint HandleCloseCB(
	GtkWidget *widget, gpointer *event, gpointer data
);

static void CListUnselectRowCB(
        GtkWidget *widget,
        gint row, gint column,
        GdkEventButton *event, gpointer data
);

/* DND specific event/signal callbacks. */
static void DNDBeginCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
);
static void DNDEndCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
);
static gboolean DNDDragMotionCB(
        GtkWidget *widget, GdkDragContext *dc,
        gint x, gint y, guint t,
        gpointer data
);


static void DNDDataRecievedCB(
        GtkWidget *widget, GdkDragContext *dc,
        gint x, gint y, GtkSelectionData *selection_data,  
        guint info, guint t, gpointer data 
);


/* Some convience functions for our example. */
static my_prog_window_struct *WindowNew(const gchar *title , gint x , gint y , gint xs , gint ys );
static void WindowDelete(my_prog_window_struct *win);

/*
 *	"delete_event" signal callback.
 *
 *	Called when a GtkWindow closes.
 */
static gint HandleCloseCB(
	GtkWidget *widget, gpointer *event, gpointer data
)
{
	/* Make it simple, when one window closes we just effectively
	 * close them all by breaking out of the last GTK+ main loop
	 * so that they will all be destroyed.
	 */
	gtk_main_quit();

        return(TRUE);
}



/*
 *	DND "drag_begin" handler, this is called whenever a drag starts.
 */
static void DNDBeginCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
)
{
        my_prog_window_struct *win = (my_prog_window_struct *)data;
        if((widget == NULL) || (win == NULL) || (dc == NULL))
		return;

	/* Put any needed drag begin setup code here. */
}

/*
 *      DND "drag_end" handler, this is called when a drag and drop has
 *	completed. So this function is the last one to be called in
 *	any given DND operation.
 */
static void DNDEndCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
)
{
        my_prog_window_struct *win = (my_prog_window_struct *)data;
        if((win == NULL) || (dc == NULL))
                return;

	/* Put any needed drag end cleanup code here. */
}

/*
 *	DND "drag_motion" handler, this is called whenever the 
 *	pointer is dragging over the target widget.
 */
static gboolean DNDDragMotionCB(
        GtkWidget *widget, GdkDragContext *dc,
        gint x, gint y, guint t,
        gpointer data
)
{


	return(FALSE);


	gboolean same_widget;
	GdkDragAction suggested_action;
	GtkWidget *src_widget, *tar_widget;
	my_prog_window_struct *win = (my_prog_window_struct *)data;
        if((win == NULL) || (dc == NULL))
                return(FALSE);

	/* Get source widget and target widget. */
	src_widget = gtk_drag_get_source_widget(dc);
	tar_widget = widget;

	/* Note if source widget is the same as the target. */
	same_widget = (src_widget == tar_widget) ? TRUE : FALSE;


	/* If this is the same widget, our suggested action should be
	 * move.  For all other case we assume copy.
	 */

	if(same_widget)
		suggested_action = GDK_ACTION_MOVE;
	else
		suggested_action = GDK_ACTION_COPY;




	/* Respond with default drag action (status). First we check
	 * the dc's list of actions. If the list only contains
	 * move, copy, or link then we select just that, otherwise we
	 * return with our default suggested action.
	 * If no valid actions are listed then we respond with 0.
	 */

        /* Only move? */
        if(dc->actions == GDK_ACTION_MOVE)
            gdk_drag_status(dc, GDK_ACTION_MOVE, t);
        /* Only copy? */
        else if(dc->actions == GDK_ACTION_COPY)
            gdk_drag_status(dc, GDK_ACTION_COPY, t);
        /* Only link? */
        else if(dc->actions == GDK_ACTION_LINK)
            gdk_drag_status(dc, GDK_ACTION_LINK, t);
        /* Other action, check if listed in our actions list? */
        else if(dc->actions & suggested_action)
            gdk_drag_status(dc, suggested_action, t);
        /* All else respond with 0. */
        else
            gdk_drag_status(dc, 0, t);

	return(FALSE);
}


/*
 *      DND "drag_data_received" handler. When DNDDataRequestCB()
 *	calls gtk_selection_data_set() to send out the data, this function
 *	recieves it and is responsible for handling it.
 *
 *	This is also the only DND callback function where the given
 *	inputs may reflect those of the drop target so we need to check
 *	if this is the same structure or not.
 */



static void DNDDataRecievedCB(
	GtkWidget *widget, GdkDragContext *dc,
	gint x, gint y, GtkSelectionData *selection_data,
	guint info, guint t, gpointer data
)
{
	gboolean same;
	gint row, column;
	GtkWidget *source_widget;


        my_prog_window_struct *win = (my_prog_window_struct *)data;
        if((widget == NULL) || (win == NULL) || (dc == NULL))
                return;


        /* Source and target widgets are the same? */
	source_widget = gtk_drag_get_source_widget(dc);
        same = (source_widget == widget) ? TRUE : FALSE;

if (same == TRUE)
 return;

	/* Important, check if we actually got data.  Sometimes errors
	 * occure and selection_data will be NULL.
	 */
	if(selection_data == NULL)
		return;
        if(selection_data->length < 0)
                return;


	if((info == DRAG_TAR_INFO_0) ||
           (info == DRAG_TAR_INFO_1) ||
           (info == DRAG_TAR_INFO_2)
	)
	{


           new_text = selection_data->data;


         
          int ic = 0;
          int myselection = 0;

          for(ic=0;ic<iconcounter;ic++){
            if ( GTK_BUTTON(widget) == button[ic]){
            //  printf("ok ---------------------------------------- %d\n" , ic); 
             myselection = ic;
            }
          }


	while(strstr(new_text,"\r\n"))strrepl(new_text,1024,"\r\n","");

         sprintf(mycmd , "%s \"%s\" &" , action[myselection].torun , new_text);


	//printf("%sn",mycmd);
         system(mycmd);



         //free(mycmd);
         //free(new_text);
	}
}



/*
 *	Creates a new window with everything set up.
 */


static my_prog_window_struct *WindowNew(const gchar *title , gint x , gint y , gint xs , gint ys)
{
	gchar *heading[1];
	GtkWidget *w;
        //static EggTrayIcon *egg = NULL;
	GtkWidget *egg;

	GtkWidget *eventbox;
	GtkWidget  *parent, *scrolled_window;

	GtkTargetEntry target_entry[3];
	my_prog_window_struct *win = (my_prog_window_struct *)g_malloc0(
		sizeof(my_prog_window_struct)
	);
	if(win == NULL)
	    return(NULL);

	/* Create toplevel. */
//        w = gtk_window_new(GTK_WINDOW_TOPLEVEL);

//        w = gtk_window_new(GTK_WINDOW_POPUP);
//win->toplevel = w;


 egg = gtk_window_new(GTK_WINDOW_TOPLEVEL);
//        egg = egg_tray_icon_new("freemem");

        eventbox = gtk_event_box_new();
//	win->toplevel = eventbox;
	win->toplevel = egg;
        gtk_container_add(GTK_CONTAINER(egg), eventbox);

        gtk_signal_connect(
            GTK_OBJECT(eventbox), "delete_event",
            GTK_SIGNAL_FUNC(HandleCloseCB), win
        );
        gtk_signal_connect(
            GTK_OBJECT(egg), "delete_event",
            GTK_SIGNAL_FUNC(HandleCloseCB), egg
        );
	gtk_widget_set_usize(GTK_WIDGET(eventbox), xs, ys);
	gtk_widget_set_usize(GTK_WIDGET(egg), xs, ys);
        gtk_widget_set_uposition(GTK_WIDGET(egg), x,y );

	gtk_window_set_decorated(GTK_WINDOW(egg),0);
	gtk_window_set_keep_below (GTK_WINDOW(egg),1);
//	gtk_window_set_type_hint (GTK_WINDOW(egg),GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU);
	gtk_window_set_type_hint (GTK_WINDOW(egg),GDK_WINDOW_TYPE_HINT_TOOLBAR);

gtk_window_set_skip_taskbar_hint(GTK_WINDOW(egg),1);
gtk_window_stick(GTK_WINDOW(egg));

        gtk_window_set_title(
	    GTK_WINDOW(egg),
	    (title == NULL) ? "DnDesk" : title
	);

	/* Do not show the toplevel just yet. */
	//parent = w;

parent = eventbox; 
        /* Main vbox to hold button */
//        w = gtk_vbox_new(FALSE, 0);
 w = gtk_vbox_new(1,1);
        //gtk_container_add(GTK_CONTAINER(egg), w);

	gtk_container_add(GTK_CONTAINER(parent), w);
	

        gtk_widget_show(w);
        parent = w;



        w = gtk_button_new();
	button[iconcounter]= GTK_BUTTON(w);
	win->button = w;
	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);


        GtkTooltips *button_bar_tips;
        button_bar_tips = gtk_tooltips_new();
   gtk_tooltips_set_tip(GTK_TOOLTIPS (button_bar_tips), w, action[iconcounter].tooltip, "");


	/* Realize the clist widget and make sure it has a window,
	 * this will be for DND setup.
	 */

gtk_widget_realize(w);
		/* DND: Set up the clist as a potential DND destination.
		 * First we set up target_entry which is a sequence of of
		 * structure which specify the kinds (which we define) of
		 * drops accepted on this widget.
		 */

		/* Set up the list of data format types that our DND
		 * callbacks will accept.
		 */
		target_entry[0].target = DRAG_TAR_NAME_0;
		target_entry[0].flags = 0;
		target_entry[0].info = DRAG_TAR_INFO_0;
                target_entry[1].target = DRAG_TAR_NAME_1;
                target_entry[1].flags = 0;
                target_entry[1].info = DRAG_TAR_INFO_1;
                target_entry[2].target = DRAG_TAR_NAME_2;
                target_entry[2].flags = 0;
                target_entry[2].info = DRAG_TAR_INFO_2;

		/* Set the drag destination for this widget, using the
		 * above target entry types, accept move's and coppies'.
		 */

		gtk_drag_dest_set(
			w,
			GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT |
			GTK_DEST_DEFAULT_DROP,
			target_entry,
			sizeof(target_entry) / sizeof(GtkTargetEntry),
			GDK_ACTION_MOVE | GDK_ACTION_COPY
		);


                gtk_signal_connect(
                        GTK_OBJECT(w), "drag_end",
                        GTK_SIGNAL_FUNC(DNDEndCB), win
                );

                gtk_signal_connect(
                        GTK_OBJECT(w), "drag_data_received",
                        GTK_SIGNAL_FUNC(DNDDataRecievedCB), win
                );


    /* Connect the "clicked" signal of the button to our callback */


    gtk_signal_connect (GTK_OBJECT (w), "button_press_event",
                        GTK_SIGNAL_FUNC (button_click), NULL);

        gtk_widget_show( pixmapwid );
        gtk_container_add( GTK_CONTAINER(button[iconcounter]), pixmapwid );
	gtk_widget_show_all(egg);
gtk_widget_show(GTK_WIDGET(egg));
	gtk_widget_show(win->toplevel);


//        gtk_widget_shape_combine_mask( EGG_TRAY_ICON(egg), mask, 0, 0 );

  gtk_widget_shape_combine_mask( GTK_WIDGET (egg), mask, 0, 0 );

 //       gtk_widget_shape_combine_mask(gtk_widget_get_parent(GTK_WIDGET (egg)) , mask, 0, 0 );

// gtk_widget_shape_combine_mask(button[iconcounter], mask, 0, 0 );
// gtk_widget_shape_combine_mask(pixmapwid , mask, 0, 0 );

	/* Now show the toplevel. */

	return(win);
}

/*
 *	Dealloactes the given window and all its resources.
 */
static void WindowDelete(my_prog_window_struct *win)
{
	GtkWidget *w;


	if(win == NULL)
		return;

	/* Destroy the GtkCList, first remove the DND settings on it
	 * and then destroy it.
	 */
	w = win->button;
	if(w != NULL)
	{
		/* Remove DND settings on this widget. */
		gtk_drag_dest_unset(w);
		gtk_drag_source_unset(w);

		win->button = NULL;
		gtk_widget_destroy(w);
	}

	/* Destroy toplevel GtkWindow, thus destroying all of its
	 * child widgets.
	 */
	w = win->toplevel;
	if(w != NULL)
	{
		win->toplevel = NULL;
		gtk_widget_destroy(w);
	}

	/* Deallocate the structure itself. */
	g_free(win);
}

static gint timeout_handler ( gpointer data ); 
int main(int argc, char **argv)
{
	GtkStyle *style;
	GdkWindow *window;

	

 //       GtkWidget *pixmapwid;

	gtk_init(&argc, &argv);



	/* Load the pixmaps that we will be using as GtkCList cell
	 * pixmaps and DND icons.
	 *
	 * This requires that we use the root window for loading of
	 * the pixmaps (hence the need to include gdk/gdkx.h).
	 */
	style = gtk_widget_get_default_style();
	window = (GdkWindow *)GDK_ROOT_PARENT();


	/* Create window */
        parseConfigFile();


  /* Add a timeout to update the display once a second */
  gtk_timeout_add ( 200, timeout_handler, NULL );


	/* Enter main gtk loop. */
	gtk_main();


	/* Application now shutting down, begin deallocating
	 * resources.
	 */
        int ec=0;
        for(ec=0;ec<iconcounter;ec++){
	   WindowDelete(win[ec]);
        }


	return(0);
}

gint oldstamp;
gint newstamp;
#include <sys/stat.h>
struct stat stat_modified;
struct stat stat_modifiedold;

gint tstat_modified;
gint tstat_modifiedold;
gint ppx;
gint ppy;
gchar flushtest[1000];
static gint timeout_handler ( gpointer data ) {

sprintf(flushtest , "flushtest\n");

//-- this uses too much cpu!
/*
gint check=proc_exists( "testloop");

//fflush(stdout);


//printf("proctest: %d\n" , check);

if (check==0) {
	return;
}
//printf("proctest: %d\n" , check);
*/

	FILE *cFile;

    	GdkPixbuf *pixbuf;
	GdkPixmap	*pixmap;


          int ic = 0;
  // printf("ok ------ %d\n" , ic); 



          for(ic=0;ic<iconcounter;ic++){

            sprintf(thepic , action[ic].alarmpicname);

            if (  strcmp(thepic , "nopic") ){

            //  printf("ok ---------------------------------------- %d %s\n" , ic,thepic); 

/*
	           if ((cFile = fopen(thepic, "r")) != NULL)
	           {
                    fclose(cFile);
*/
stat(thepic, &stat_modified);
tstat_modified = stat_modified.st_ctime;
// printf("--%d\n" , tstat_modified);
if( tstat_modified == tstat_modifiedold){


                    if (action[ic].alarmactive == 0){
			//gtk_widget_destroy
                        gtk_container_remove( GTK_CONTAINER(button[ic]) , action[ic].buttonpic);
                        pixbuf = gdk_pixbuf_new_from_file (thepic ,0);
       	                gdk_pixbuf_render_pixmap_and_mask(pixbuf, &pixmap, &mask, 128);
			//gdk_drawable_get_size( pixmap , &ppx , &ppy);

                        pixmapwid = gtk_pixmap_new( pixmap, mask );
 //printf("ok---%s\n" , thepic);
 			gtk_widget_shape_combine_mask( GTK_WIDGET (win[ic]->toplevel), mask, 0, 0 );
                        gtk_widget_show( pixmapwid );
                        gtk_container_add( GTK_CONTAINER(button[ic]), pixmapwid );
                        action[ic].alarmactive = 1;
              		action[ic].buttonpic = pixmapwid;
			gdk_flush();
			gdk_pixbuf_unref(pixbuf);
			g_object_unref(pixmap);
			g_object_unref(mask);

                     }
                     }else{

 //printf("debug---\n" );
/*
                        gtk_container_remove( GTK_CONTAINER(button[ic]) , action[ic].buttonpic);
       	                gdk_pixbuf_render_pixmap_and_mask(action[ic].ipixbuf, &pixmap, &mask, 128);
                        pixmapwid = gtk_pixmap_new( pixmap, mask );
                        gtk_widget_show( pixmapwid );
                        gtk_container_add( GTK_CONTAINER(button[ic]), pixmapwid );

              		action[ic].buttonpic = pixmapwid;
*/
                        action[ic].alarmactive = 0;
                      }

            }
          }
tstat_modifiedold = tstat_modified;
}

//void button_click( GtkWidget *widget,
//               gpointer   data)

void button_click( GtkWidget *widget,
               GdkEventButton    *event)
{
    // g_print ("Button was pressed\n");
 
     // printf("+++%d\n" , event->button);

    //gchar mycmd[20000];
    int ic = 0;
    int myselection = 0;
    for(ic=0;ic<iconcounter;ic++){
      if ( GTK_BUTTON(widget) == button[ic]){
        myselection = ic;
      }
    }


    if(event->button == 1){
       if(!strcmp(action[myselection].torunclick1 , "INTERNtoggle-visibility")){
          hideWindows();
       }else{
         sprintf(mycmd , "%s" , action[myselection].torunclick1 );
         system(mycmd);
       }
    }
    if(event->button == 2){
       if(!strcmp(action[myselection].torunclick2 , "INTERNtoggle-visibility")){
          hideWindows();
       }else{
         sprintf(mycmd , "%s" , action[myselection].torunclick2 );
         system(mycmd);
       }
    }
    if(event->button == 3){
       if(!strcmp(action[myselection].torunclick3 , "INTERNtoggle-visibility")){
          hideWindows();
       }else{
         sprintf(mycmd , "%s" , action[myselection].torunclick3 );
         system(mycmd);
       }
    }


   // g_free(mycmd);
}

static void WindowHide(my_prog_window_struct *win)
{
	GtkWidget *w;
	if(win == NULL)
		return;

	w = win->toplevel;
	if(w != NULL)
	{
        if ( hidden == 0 ){
                gtk_widget_hide(w);
        }else{
                gtk_widget_show(w);
        }
	}

}

void hideWindows(void)
{
	
    int ec=0;
    for(ec=1;ec<iconcounter;ec++){
      WindowHide(win[ec]);
    }
    if ( hidden == 0 ){
      hidden = 1;
    }else{
      hidden = 0;
    }
}

void parseConfigFile(void)
{
	FILE *configFile;
	FILE *existenceCheck;

        char configuration[1024];
	sprintf(configuration,"deskicons.rc");
	char token[1024];


char theline[1024];

        
        char cmdname[1024];
	    int x=0;
        int y=0;
        int xs=0;
        int ys=0;

    	GdkPixbuf *pixbuf;
	GdkPixmap	*pixmap;

	memset(&action,0,sizeof(action));  


	if ((configFile = fopen(configuration, "r")) == NULL)
	{
		fprintf(stderr, "\ndnd: Could not locate or open the config file (%s).. Giving up.\n\n",configuration);
		exit (1);
	}
	while(fscanf(configFile,"%s",token)!=EOF) 
	{

		if(!strcmp(token,"CREATENEWICON"))
		{

			fscanf(configFile,"%d",&x);
			fscanf(configFile,"%d",&y);
			fscanf(configFile,"%d",&xs);
			fscanf(configFile,"%d",&ys);
			fscanf(configFile,"%s",&action[iconcounter].picname);
            
			fscanf(configFile,"%s",&action[iconcounter].alarmpicname);
            



            fscanf(configFile,"%s",&theline);
            while(strstr(theline,"_"))strrepl(theline,1024,"_"," ");
            strcpy(action[iconcounter].tooltip , theline);

            fscanf(configFile,"%s",&theline);
            while(strstr(theline,"#"))strrepl(theline,1024,"#"," ");
            strcpy(action[iconcounter].torun , theline);

            fscanf(configFile,"%s",&theline);
            while(strstr(theline,"#"))strrepl(theline,1024,"#"," ");
            strcpy(action[iconcounter].torunclick1 , theline);

            fscanf(configFile,"%s",&theline);
            while(strstr(theline,"#"))strrepl(theline,1024,"#"," ");
            strcpy(action[iconcounter].torunclick2 , theline);

            fscanf(configFile,"%s",&theline);
            while(strstr(theline,"#"))strrepl(theline,1024,"#"," ");
            strcpy(action[iconcounter].torunclick3 , theline);

//printf("%s\n" , action[iconcounter].tooltip);

  action[iconcounter].alarmactive=0;
//            if ( ! strcmp(action[iconcounter].alarmpicname , "nopic") ){
//  		action[iconcounter].alarmactive=1;
//            }
                        action[iconcounter].ipixbuf = gdk_pixbuf_new_from_file (action[iconcounter].picname,0);
       	                gdk_pixbuf_render_pixmap_and_mask(action[iconcounter].ipixbuf, &pixmap, &mask, 128);
                        pixmapwid = gtk_pixmap_new( pixmap, mask );
                        action[iconcounter].buttonpic = pixmapwid;
                        
                	win[iconcounter] = WindowNew("DnDesk" , x , y ,xs , ys);
			gdk_pixbuf_unref(action[iconcounter].ipixbuf);
			g_object_unref(pixmap);
			g_object_unref(mask);
                        iconcounter += 1;
		}

	}
fclose(configFile);

}
char *strrepl(char *Str, size_t BufSiz, char *OldStr, char *NewStr)
{
      int OldLen, NewLen;
      char *p, *q;

      if(NULL == (p = strstr(Str, OldStr)))
            return Str;
      OldLen = strlen(OldStr);
      NewLen = strlen(NewStr);
      if ((strlen(Str) + NewLen - OldLen + 1) > BufSiz)
            return NULL;
      memmove(q = p+NewLen, p+OldLen, strlen(p+OldLen)+1);
      memcpy(p, NewStr, NewLen);
      return q;
}


/*
#include <stdio.h>
#include <ctype.h>
#include <string.h>
#include <dirent.h>
#include <stdlib.h>



#define READ_BUF_SIZE	50
int proc_exists( char* pidName)
{
	DIR *dir;
	struct dirent *next;

	int i=0;

	dir = opendir("/proc");
	//if (!dir)
		//perror_msg_and_die("Cannot open /proc");
	
	while ((next = readdir(dir)) != NULL) {
		FILE *status;
		char filename[READ_BUF_SIZE];
		char buffer[READ_BUF_SIZE];
		char name[READ_BUF_SIZE];

		// Must skip ".." since that is outside /proc //
		if (strcmp(next->d_name, "..") == 0)
			continue;

		// If it isn't a number, we don't want it //
		if (!isdigit(*next->d_name))
			continue;

		sprintf(filename, "/proc/%s/status", next->d_name);
		if (! (status = fopen(filename, "r")) ) {
			continue;
		}
		if (fgets(buffer, READ_BUF_SIZE-1, status) == NULL) {
			fclose(status);
			continue;
		}
		fclose(status);

		// Buffer should contain a string like "Name:   binary_name" //
		sscanf(buffer, "%*s %s", name);
		if (strcmp(name, pidName) == 0) {
			closedir(dir);
			return 1;
		}
	}

	return 0;
}
*/
